@@ -188,7 +188,7 @@ def piggo_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
             "color": "0",
             "font": "0",
             "size": "0",
-            "descr": file1.douban_info+'\n'+file1.screenshoturl,
+            "descr": file1.pathinfo.contenthead+'\n'+file1.douban_info+'\n'+file1.screenshoturl+'\n'+file1.pathinfo.contenttail,
             "technical_info": file1.mediainfo,
             "type": select_type,
             "source_sel": source_sel,
